@@ -66,7 +66,6 @@ int				dbstatements = 0;
 #define SQLNODATAOK(r)	((r) == SQL_SUCCESS || (r) == SQL_SUCCESS_WITH_INFO || (r) == SQL_NO_DATA || (r) == SQL_NO_DATA_FOUND)
 
 extern int		loglevel;
-extern bloomfilter_t	bloomfilter;
 static globus_mutex_t	rlidbmtx;
 
 static char		*objtype2table(globus_rls_obj_type_t objtype,
@@ -385,7 +384,7 @@ db_update_delete(void *hv, char *rli_url, char *pattern, char *errmsg)
   SQLINTEGER rli_id;
   int		rc;
   SQLRETURN	r;
-  SQLINTEGER	rows    = 0;
+  SQLLEN	rows    = 0;
 
   if (loglevel > 1)
     logit(LOG_DEBUG, "db_update_delete: %s %s", rli_url, PS(pattern));
@@ -591,7 +590,7 @@ db_attr_delete(void *hv, char *name, globus_rls_obj_type_t objtype,
   int				rc;
   long				attr_id = 0;
   long              type    = 0;
-  SQLINTEGER			len;
+  SQLLEN			len;
   char				*valtab;
   long				count   = 0;
 
@@ -700,7 +699,6 @@ db_attr_modify(void *hv, char *key, char *name, globus_rls_obj_type_t objtype,
   globus_rls_attr_type_t	atype;
   SQLINTEGER		obj_id;
   char				*valtab;
-  SQLINTEGER		rows    = 0;
   char				dbuf[100];
 
   if (loglevel > 1)
@@ -748,17 +746,8 @@ db_attr_modify(void *hv, char *key, char *name, globus_rls_obj_type_t objtype,
     rc = GLOBUS_RLS_DBERROR;
     goto error;
   }
-  if (SQLOK(r)) {
-    SQLRowCount(h->stmt, &rows);
-  }
-  else {
-    rows = 0;
-  }
-  if (rows != 1) {
-    snprintf(errmsg, MAXERRMSG, "%s: %s", key, name);
-    rc = GLOBUS_RLS_ATTR_NEXIST;
-    goto error;
-  }
+  /* At this point, don't check the rowcount, as it may be zero
+     if the new value is the same as the current value. */
 
   return endtran(h, SQL_COMMIT, errmsg, NULL);
 
@@ -780,7 +769,7 @@ db_attr_remove(void *hv, char *key, char *name, globus_rls_obj_type_t objtype,
   globus_rls_attr_type_t	type;
   SQLINTEGER		obj_id;
   char				*valtab;
-  SQLINTEGER		rows    = 0;
+  SQLLEN		rows    = 0;
 
   if (loglevel > 1)
     logit(LOG_DEBUG, "db_attr_remove: %s %s %d", key, name, objtype);
@@ -1023,8 +1012,7 @@ db_exists(void *hv, char *key, globus_rls_obj_type_t objtype, char *errmsg)
   char		buf[BIGBUF];
   char		*objtab;
   int		nferr;
-  long		rows    = 0;
-  SQLINTEGER	len;
+  long       	rows    = 0;
   SQLRETURN	r;
 
   if (loglevel > 1)
@@ -1045,7 +1033,7 @@ db_exists(void *hv, char *key, globus_rls_obj_type_t objtype, char *errmsg)
    * drivers (including Easysoft's Oracle driver) don't support this on
    * after a select stmt.
    */
-  r = SQLBindCol(h->stmt, 1, SQL_C_LONG, &rows, sizeof(rows), &len);
+  r = SQLBindCol(h->stmt, 1, SQL_C_LONG, &rows, 0, NULL);
   if (SQLOK(r))
     r = SQLFetch(h->stmt);
   if (!SQLOK(r))
@@ -1160,17 +1148,8 @@ db_lrc_renamelfn(void *hv, char *oldname, char *newname, char *errmsg)
     goto error;
   }
 
-  /* Commit changes and update bloomfilter */
+  /* Commit changes */
   rc = endtran(h, SQL_COMMIT, errmsg, adjcount);
-  if (rc == GLOBUS_RLS_SUCCESS) {
-    if (bloomfilter.bfsize) {
-      globus_mutex_lock(&bloomfilter.mtx);
-      bf_deletelfn(&bloomfilter, oldname);
-      bf_addlfn(&bloomfilter, newname);
-      globus_mutex_unlock(&bloomfilter.mtx);
-    }
-  }
-
   return rc;
 
 error:
@@ -1335,14 +1314,6 @@ db_lrc_create(void *hv, char *lfn, char *pfn, char *errmsg)
   adjcount[T_LRCMAP]++;
 
   rc = endtran(h, SQL_COMMIT, errmsg, adjcount);
-  if (rc == GLOBUS_RLS_SUCCESS) {
-    if (bloomfilter.bfsize) {
-      globus_mutex_lock(&bloomfilter.mtx);
-      bf_addlfn(&bloomfilter, lfn);
-      globus_mutex_unlock(&bloomfilter.mtx);
-    }
-  }
-
   return rc;
 
  error:
@@ -1362,7 +1333,7 @@ db_lrc_delete(void *hv, char *lfn, char *pfn, int *lfndeleted, char *errmsg)
   SQLINTEGER	pfn_ref;
   int		rc;
   SQLRETURN	r;
-  SQLINTEGER	rows    = 0;
+  SQLLEN	rows    = 0;
   int		adjcount[T_NUM];
 
   if (loglevel > 1)
@@ -1443,14 +1414,6 @@ db_lrc_delete(void *hv, char *lfn, char *pfn, int *lfndeleted, char *errmsg)
   }
 
   rc = endtran(h, SQL_COMMIT, errmsg, adjcount);
-  if (*lfndeleted && rc == GLOBUS_RLS_SUCCESS) {
-    if (bloomfilter.bfsize) {
-      globus_mutex_lock(&bloomfilter.mtx);
-      bf_deletelfn(&bloomfilter, lfn);
-      globus_mutex_unlock(&bloomfilter.mtx);
-    }
-  }
-
   return rc;
 
  error:
@@ -1500,7 +1463,7 @@ db_lrc_mapping_exists(void *hv, char *lfn, char *pfn, char *errmsg)
   db_handle_t	*h = (db_handle_t *) hv;
   char		buf[BIGBUF];
   long		rows    = 0;
-  SQLINTEGER	len;
+  SQLLEN	len;
   SQLRETURN	r;
 
   if (loglevel > 1)
@@ -1559,7 +1522,7 @@ db_rli_delete(void *hv, char *lfn, char *lrc, char *sender, int *lfndeleted,
   SQLINTEGER	sender_id;
   int		rc;
   SQLRETURN	r;
-  SQLINTEGER	rows    = 0;
+  SQLLEN	rows    = 0;
   int		adjcount[T_NUM];
 
   if (loglevel > 1)
@@ -1672,7 +1635,7 @@ db_rli_expire(void *hv, char *sender, time_t rlistaleint, char *errmsg)
   long  	lfn_id  = 0;
   long  	lrc_id  = 0;
   SQLINTEGER	sender_id;
-  SQLINTEGER	len;
+  SQLLEN	len;
   IDLIST	*lfnids = NULL;
   IDLIST	*lrcids = NULL;
   IDLIST	*p;
@@ -1680,7 +1643,7 @@ db_rli_expire(void *hv, char *sender, time_t rlistaleint, char *errmsg)
   SQLRETURN	r;
   int		rc;
   int		mapdelcnt;
-  SQLINTEGER	rows    = 0;
+  SQLLEN	rows    = 0;
   int		adjcount[T_NUM];
   char		dbuf[100];
 
@@ -1852,7 +1815,7 @@ db_rli_mapping_exists(void *hv, char *lfn, char *lrc, char *errmsg)
   db_handle_t	*h = (db_handle_t *) hv;
   char		buf[BIGBUF];
   long		rows    = 0;
-  SQLINTEGER	len;
+  SQLLEN	len;
   SQLRETURN	r;
 
   if (loglevel > 1)
@@ -1900,7 +1863,7 @@ db_rli_update(void *hv, char *lfn, char *lrc, char *sender, char *ts,
   long  	lrc_id      = 0;
   long  	sender_id   = 0;
   SQLRETURN	r;
-  SQLINTEGER	len;
+  SQLLEN	len;
   int		adjcount[T_NUM];
   char		dbuf[100];
 
@@ -2060,7 +2023,7 @@ query_ret1(db_handle_t *h, char *buf, char *key,
 {
   SQLRETURN	r;
   SQLCHAR		buf1[BUFLEN];
-  SQLINTEGER	len;
+  SQLLEN	len;
 
   r = SQLExecDirect(h->stmt, (SQLCHAR *) buf, SQL_NTS);
   if (!SQLOK(r)) {
@@ -2104,7 +2067,7 @@ query_ret2(db_handle_t *h, char *buf, char *key, db_str2_callback_t cb,
   SQLRETURN	r;
   SQLCHAR		buf1[BUFLEN];
   SQLCHAR		buf2[BUFLEN];
-  SQLINTEGER	len;
+  SQLLEN	len;
 
   r = SQLExecDirect(h->stmt, (SQLCHAR *) buf, SQL_NTS);
   if (!SQLOK(r)) {
@@ -2152,7 +2115,7 @@ query_ret3(db_handle_t *h, char *buf, char *key, db_str3_callback_t cb,
   SQLCHAR		buf1[BUFLEN];
   SQLCHAR		buf2[BUFLEN];
   SQLCHAR		buf3[BUFLEN];
-  SQLINTEGER	len;
+  SQLLEN	len;
 
   r = SQLExecDirect(h->stmt, (SQLCHAR *) buf, SQL_NTS);
   if (!SQLOK(r)) {
@@ -2204,7 +2167,7 @@ query_ret4(db_handle_t *h, char *buf, char *key, db_str4_callback_t cb,
   SQLCHAR		buf2[BUFLEN];
   SQLCHAR		buf3[BUFLEN];
   SQLCHAR		buf4[BUFLEN];
-  SQLINTEGER	len;
+  SQLLEN	len;
 
   r = SQLExecDirect(h->stmt, (SQLCHAR *) buf, SQL_NTS);
   if (!SQLOK(r)) {
@@ -2257,8 +2220,8 @@ updateref(db_handle_t *h, int tidx, char *name, int adjust, int insert,
 
 {
   char		buf[BIGBUF];
-  SQLINTEGER	rows    = 0;
-  SQLINTEGER	len;
+  SQLLEN	rows    = 0;
+  SQLLEN	len;
   SQLRETURN	r;
   SQLINTEGER	tref;
   long      idbuf   = 0;
@@ -2336,7 +2299,7 @@ gettablecount(db_handle_t *h, int tidx)
 
 {
   SQLRETURN	r;
-  SQLINTEGER	len;
+  SQLLEN	len;
   char		buf[BIGBUF];
   char		errmsg[MAXERRMSG];
   long      lbuf    = 0;
@@ -2373,7 +2336,7 @@ getid(db_handle_t *h, char *s, char *tab, int nferr, SQLINTEGER *id,
 
 {
   char		buf[BIGBUF];
-  SQLINTEGER	len;
+  SQLLEN	len;
   SQLRETURN	r;
   long      lbuf    = 0;
 
@@ -2429,7 +2392,7 @@ deleteattrvals(db_handle_t *h, globus_rls_obj_type_t objtype, SQLINTEGER obj_id)
   char		buf[BIGBUF];
   int		i;
   SQLRETURN	r;
-  SQLINTEGER	len;
+  SQLLEN	len;
   long		attr_id = 0;
   long		type    = 0;
   char		*valtab;
@@ -2493,7 +2456,7 @@ attrinfo(db_handle_t *h, globus_rls_obj_type_t objtype, char *name, char *key,
   char		buf[BIGBUF];
   SQLRETURN	r;
   int		rc;
-  SQLINTEGER	len;
+  SQLLEN	len;
   char		*table;
   int		nferr;
   long      attr_id_buf = 0;
@@ -2595,7 +2558,7 @@ seterr_insert(db_handle_t *h, SQLRETURN r, char *table, char *name, int err,
 {
   char		buf[BIGBUF];
   long		rows    = 0;
-  SQLINTEGER	len;
+  SQLLEN	len;
   
   odbcerr(r, SQL_HANDLE_STMT, h->stmt, errmsg);
   snprintf(buf, BIGBUF, "select count(*) from %s where name = '%s'", table, name);
@@ -2639,7 +2602,7 @@ seterr_insertattr(db_handle_t *h, SQLRETURN r, char *table, int obj_id,
 {
   char		buf[BIGBUF];
   long		rows    = 0;
-  SQLINTEGER	len;
+  SQLLEN	len;
   
   odbcerr(r, SQL_HANDLE_STMT, h->stmt, errmsg);
   snprintf(buf, BIGBUF, "select count(*) from %s where obj_id = %d and attr_id = %d",
@@ -2682,7 +2645,7 @@ seterr_insertmap(db_handle_t *h, SQLRETURN r, char *c1, int id1, char *c2,
 {
   char		buf[BIGBUF];
   long		rows    = 0;
-  SQLINTEGER	len;
+  SQLLEN	len;
   
   odbcerr(r, SQL_HANDLE_STMT, h->stmt, errmsg);
   if (c3)
