@@ -18,7 +18,23 @@
  * Definitions for RLI data used by LRC for LRC -> RLI updates.
  */
 
-extern int	lrc_init(char *dbname, char *db_user, char *db_pwd);
+/* The function declaration should be as void *function_name (void *arg)
+This is required by the pthread_create routine. */
+
+extern void *lrc_init(void*);
+
+/* the original declaration of the lrc_init function has three args. But none of
+them were needed to be passed as all the three were extern variables. However
+to preserve the old declaration of lrc_init, declare a structure with elements
+db_name, db_user and db_passwd. */
+
 extern void	lrc_end();
 extern void	lrc_getbf(void *lrch);
 void		lrc_updatenow();
+extern globus_bool_t is_lrc_init_done();
+
+typedef struct lrc_init_args_s {
+  char *dbname;
+  char *db_user;
+  char *db_pwd;
+} lrc_init_args_t;
