@@ -18,5 +18,7 @@
 
 extern void	detach(char *prog);
 extern void	writepid(char *prog);
+extern globus_result_t log_init();
+extern globus_result_t log_destroy();
 extern void	logit(int level, char *fmt, ...);
 extern char	*globuserr(globus_result_t r, char *buf);
